@@ -26,20 +26,29 @@ import pyleoclim as pyleo
 from urllib.request import urlopen
 import json
 
+from pyleoclim.tests.examples import load_dataset
+
 # For some of the testing importa JSON file with a dictionary of possible LiDPs
 
-def  importLiPD():
+def importLiPD():
     url = 'https://raw.githubusercontent.com/LinkedEarth/Pyleoclim_util/Development/example_data/lipds.json'
     response = urlopen(url)
     d = json.loads(response.read())
     return d
+    
+def load_data():
+    #Loads stott MD982176 record
+    try:
+        d = pyleo.Lipd(usr_path='http://wiki.linked.earth/wiki/index.php/Special:WTLiPD?op=export&lipdid=MD982176.Stott.2004')
+    except:
+        d = pyleo.Lipd('./example_data/MD982176.Stott.2004.lpd')
+    return d
 
 class TestUiLipdTo_tso():
     ''' Test Lipd.to_tso()
     '''
     def test_to_tso_t0(self):
-        
-        d=pyleo.Lipd('http://wiki.linked.earth/wiki/index.php/Special:WTLiPD?op=export&lipdid=MD98-2170.Stott.2004')
+        d=load_data()
         ts=d.to_tso()
         assert len(ts)>0
 
@@ -48,7 +57,7 @@ class TestUiLipdExtract():
     '''
     
     def test_extract_t0(self):
-        D= importLiPD()
+        D = importLiPD()
         d = pyleo.Lipd(lipd_dict=D)
         name = 'Eur-SpannagelCave.Mangini.2005'
         d2=d.extract(name)
@@ -59,20 +68,19 @@ class TestUiLipdTo_LipdSeriesList():
     ''' Test Lipd.to_LipdSeriesList
     '''
     def test_to_LipdSeriesList_t0(self):
-        d=pyleo.Lipd('http://wiki.linked.earth/wiki/index.php/Special:WTLiPD?op=export&lipdid=MD98-2170.Stott.2004')
+        d=load_data()
         ts=d.to_LipdSeriesList()
 
 class TestUiLipdTo_LipdSeries():
     ''' Test Lipd.to_LipdSeries
     '''
     def test_to_LipdSeries_t0(self):
-        d=pyleo.Lipd('http://wiki.linked.earth/wiki/index.php/Special:WTLiPD?op=export&lipdid=MD98-2170.Stott.2004')
+        d=load_data()
         ts=d.to_LipdSeries(number=5)
 
 class TestUiLipdMapAllArchive():
     ''' Test Lipd.mapAllArchive
     '''
     def test_mapAllArchive_t0(self):
-        D= importLiPD()
-        d = pyleo.Lipd(lipd_dict=D)
+        d=load_data()
         res = d.mapAllArchive(mute=True)
\ No newline at end of file
